Module: Axlsx::Ar::SingletonMethods
- Defined in:
- lib/acts_as_xlsx/ar.rb
Overview
Singleton methods for the mixin
Instance Method Summary collapse
-
#to_xlsx(options = {}) ⇒ Object
Maps the AR class to an Axlsx package options are passed into AR find.
Instance Method Details
#to_xlsx(options = {}) ⇒ Object
Maps the AR class to an Axlsx package options are passed into AR find
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/acts_as_xlsx/ar.rb', line 48 def to_xlsx( = {}) if self.xlsx_columns.nil? self.xlsx_columns = self.column_names.map { |c| c = c.to_sym } end row_style = .delete(:style) header_style = .delete(:header_style) || row_style types = [.delete(:types) || []].flatten i18n = if .key?(:i18n) .delete(:i18n) else self.xlsx_i18n end # columns => [["column_name", "header"], [...], ...] columns = Array.wrap(.delete(:columns) || self.xlsx_columns).flat_map { |col| col.is_a?(Hash) ? col.to_a : [[col, nil]] } headers = .delete(:headers) headers||= columns.map { |(col_name, col_header)| if col_header col_header elsif i18n == true self.human_attribute_name(col_name) elsif i18n I18n.t("#{i18n_key}.#{self.name.underscore}.#{col_name}", default: col_name.to_s.humanize) else col_name.to_s.humanize end } p = .delete(:package) || Package.new row_style = p.workbook.styles.add_style(row_style) unless row_style.nil? header_style = p.workbook.styles.add_style(header_style) unless header_style.nil? i18n_key = i18n == true ? 'activerecord.attributes' : i18n sheet_name = .delete(:name) || (i18n ? (i18n == true ? self.model_name.human : I18n.t("#{i18n_key}.#{table_name.underscore}", default: table_name.humanize)) : table_name.humanize) data = .delete(:data) || where([:where]).order([:order]).to_a data = data.compact.flatten return p if data.empty? p.workbook.add_worksheet(:name=>sheet_name) do |sheet| sheet.add_row headers, :style=>header_style data.each do |r| row_data = columns.map do |(column_name, _column_header)| v = r column_name.to_s.split('.').each do |method| !v.nil? ? v = v.send(method) : v = nil end v end sheet.add_row row_data, :style=>row_style, :types=>types end end p end |